@@ -1,31 +1,9 @@
 package Acme::Time::Baby;
 
 #
-# $Id: Baby.pm,v 1.12 2002/12/13 16:26:03 abigail Exp $
+# $Id: Baby.pm,v 1.7 2002/05/15 11:37:39 abigail Exp abigail $
 #
 # $Log: Baby.pm,v $
-# Revision 1.12  2002/12/13 16:26:03  abigail
-# Nothing really, just generating a new version.
-# Bloody CPAN/PAUSE doesn't think 1.11 is larger than 1.7.
-#
-# Revision 1.11  2002/09/09 19:29:01  abigail
-# Brazilian Portuguese added (Flavio S. Glock)
-#
-# Revision 1.10  2002/08/20 14:40:26  abigail
-# Documented new language (Swedish).
-# Fixed email address.
-#
-# Revision 1.9  2002/08/20 14:34:52  abigail
-# Fixed the German:
-#    + capitalized the numbers
-#    + fixed the gender of the numbers.
-# (Torsten Hofmann and Andre Bonhote)
-#
-# Added support for Swedish (cpan #718)
-#
-# Revision 1.8  2002/08/20 13:58:08  abigail
-# Moved from RCS to CVS.
-#
 # Revision 1.7  2002/05/15 11:37:39  abigail
 # Fixed regex extracting version number from RCS Revision line.
 # (Tim Heaney)
@@ -63,7 +41,7 @@ use warnings qw /all/;
 
 use vars qw /$VERSION/;
 
-($VERSION)  = q $Revision: 1.12 $ =~ /([\d.]+)/;
+($VERSION)  = q $Revision: 1.7 $ =~ /([\d.]+)/;
 
 my %languages = (
     'en'      => {numbers => [qw /one two three four five six seven
@@ -71,15 +49,10 @@ my %languages = (
                   format  => "The big hand is on the %s " .
                              "and the little hand is on the %s"},
 
-    'br'      => {numbers => [qw /um dois trs quatro cinco seis
-                                  sete oito nove dez onze doze/],
-                  format  => "O ponteiro grande est no %s " .
-                             "e o ponteiro pequeno est no %s"},
-
-    'de'      => {numbers => [qw /Eins Zwei Drie Vier Fnf Sechs Sieben
-                                       Acht Neun Zehn Elf Zwlf/],
-                  format  => "Der grosse Zeiger ist auf der %s " .
-                             "und der kleine Zeiger ist auf der %s"},
+    'de'      => {numbers => [qw /eins zwei drie vier fnf sechs sieben
+                                       acht neun zehn elf zwlf/],
+                  format  => "Der grosse Zeiger ist auf die %s " .
+                             "und der kleine Zeiger ist auf die %s"},
 
     'du'      => {numbers => [qw /een twee drie vier vijf zes zeven
                                       acht negen tien elf twaalf/],
@@ -103,11 +76,6 @@ my %languages = (
                   format  => "Den store viseren er p %s " .
                              "og den lille viseren er p %s"},
 
-    'se'      => {numbers => [qw /ett tv tre fyra fem sex sju
-                                      tta nio tio elva tolv/],
-                  format  => "Den stora visaren r p %s " .
-                             "och den lilla visaren r p %s"},
-
     'swedish chef'
               => {numbers => [qw /one tvu three ffuoor ffeefe six
                                   sefen eight nine ten elefen tvelfe/],
@@ -177,6 +145,7 @@ sub babytime {
     sprintf $format => @numbers [$minutes, $hours];
 }
 
+
 1;
 
 __END__
@@ -212,22 +181,12 @@ options can be passed:
 =item language LANG
 
 The language the time should be told in. The following languages are
-currently supported:
+currently supported: C<en> (for English), C<de> (for German), C<du>
+(for Dutch), C<fr> (for French), C<it> (for Italian), C<no> (for
+Norwegian), C<swedish chef> (for Swedish Chef like time) and C<warez>
+(for l44+ babies).  If no language argument is given, English is used.
 
-  en             English (this is the default)
-  br             Brazilian Portuguese.
-  de             German.
-  du             Dutch.
-  fr             French.
-  it             Italian.
-  no             Norwegian.
-  se             Swedish.
-  swedish chef   Swedish Chef (from the Muppets).
-  warez          l44+.
-
-If no language argument is given, English is used.
-
-Note that some languages use accented letters. The returned 
+Note that German and Norwegian use accented letters. The returned 
 sentences are correct for an ISO 8859-1 platform.
 
 =item format STRING
@@ -270,33 +229,11 @@ Support for more languages.
 
 =head1 AUTHOR
 
-Abigail, I<acme-time-baby@abigail.nl>.
+Abigail, I<abigail@foad.org>.
 
 =head1 HISTORY
 
     $Log: Baby.pm,v $
-    Revision 1.12  2002/12/13 16:26:03  abigail
-    Nothing really, just generating a new version.
-    Bloody CPAN/PAUSE doesn't think 1.11 is larger than 1.7.
-
-    Revision 1.11  2002/09/09 19:29:01  abigail
-    Brazilian Portuguese added (Flavio S. Glock)
-
-    Revision 1.10  2002/08/20 14:40:26  abigail
-    Documented new language (Swedish).
-    Fixed email address.
-
-    Revision 1.9  2002/08/20 14:34:52  abigail
-    Fixed the German:
-       + capitalized the numbers
-       + fixed the gender of the numbers.
-    (Torsten Hofmann and Andre Bonhote)
-
-    Added support for Swedish (cpan #718)
-
-    Revision 1.8  2002/08/20 13:58:08  abigail
-    Moved from RCS to CVS.
-
     Revision 1.7  2002/05/15 11:37:39  abigail
     Fixed regex extracting version number from RCS Revision line.
     (Tim Heaney)
